Welcome to uwg's documentation!
===================================

The Urban Weather Generator (uwg) is a Python application for modeling
the `urban heat island effect <https://en.wikipedia.org/wiki/Urban_heat_island//>`_ .
Specifically, it morphs rural `EnergyPlus weather (.epw) files <http://www.ladybug.tools/epwmap//>`_ 
to reflect average conditions within the urban canyon using a range of properties.

Installation
============

``pip install -U uwg``.

To check if the command line is installed correctly use ``uwg --help``

CLI Docs
=============

For command line interface documentation and API documentation see the pages below.


.. toctree::
   :maxdepth: 2

   cli/index


uwg
================

.. toctree::
  :maxdepth: 4

  modules

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
